You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2005/01/07 17:01:19 UTC

svn commit: r124524 - in incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server: . jndi jndi/ibs schema

Author: akarasulu
Date: Fri Jan  7 08:01:15 2005
New Revision: 124524

URL: http://svn.apache.org/viewcvs?view=rev&rev=124524
Log:
pkg name refactor for top level eve classes moving them to o.a.ldap.server
Modified:
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java
   incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java	Fri Jan  7 08:01:15 2005
@@ -14,12 +14,13 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import org.apache.ldap.server.db.Database;
 import org.apache.ldap.server.db.SearchEngine;
 import org.apache.ldap.server.db.SearchEngine;
+import org.apache.ldap.server.AbstractContextPartition;
 import org.apache.ldap.common.schema.AttributeType;
 
 import javax.naming.Name ;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/BackingStore.java	Fri Jan  7 08:01:15 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import java.util.Map;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartition.java	Fri Jan  7 08:01:15 2005
@@ -14,10 +14,12 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import javax.naming.Name;
+
+import org.apache.ldap.server.BackingStore;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ContextPartitionConfig.java	Fri Jan  7 08:01:15 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import javax.naming.directory.Attributes;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/EveBackendSubsystem.java	Fri Jan  7 08:01:15 2005
@@ -1,4 +1,4 @@
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import java.util.Hashtable;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/PartitionNexus.java	Fri Jan  7 08:01:15 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import java.util.Iterator;
@@ -22,6 +22,9 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 import javax.naming.ldap.LdapContext;
+
+import org.apache.ldap.server.BackingStore;
+import org.apache.ldap.server.ContextPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/RootNexus.java	Fri Jan  7 08:01:15 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import java.util.*;
@@ -35,6 +35,9 @@
 import org.apache.ldap.common.message.LockableAttributeImpl;
 import org.apache.ldap.common.message.LockableAttributes;
 import org.apache.ldap.common.message.LockableAttributesImpl;
+import org.apache.ldap.server.BackingStore;
+import org.apache.ldap.server.ContextPartition;
+import org.apache.ldap.server.PartitionNexus;
 
                                 
 /**
@@ -160,7 +163,7 @@
 
 
     /**
-     * @see PartitionNexus#getSuffix(javax.naming.Name,
+     * @see org.apache.ldap.server.PartitionNexus#getSuffix(javax.naming.Name,
      * boolean)
      */
     public Name getSuffix( Name dn, boolean normalized ) throws NamingException
@@ -171,7 +174,7 @@
 
 
     /**
-     * @see PartitionNexus#listSuffixes(boolean)
+     * @see org.apache.ldap.server.PartitionNexus#listSuffixes(boolean)
      */
     public Iterator listSuffixes( boolean normalized ) throws NamingException
     {
@@ -191,7 +194,7 @@
 
 
     /**
-     * @see PartitionNexus#register(
+     * @see org.apache.ldap.server.PartitionNexus#register(
      * ContextPartition)
      */
     public void register( ContextPartition backend )
@@ -236,7 +239,7 @@
      * here so backend implementors do not have to worry about performing these
      * kinds of checks.
      *
-     * @see BackingStore#add(String, Name, Attributes)
+     * @see org.apache.ldap.server.BackingStore#add(String, Name, Attributes)
      */
     public void add( String updn, Name dn, Attributes an_entry ) throws NamingException
     {
@@ -352,7 +355,7 @@
 
 
     /**
-     * @see BackingStore#lookup(javax.naming.Name, String[])
+     * @see org.apache.ldap.server.BackingStore#lookup(javax.naming.Name, String[])
      */
     public Attributes lookup( Name dn, String[] attrIds )  throws NamingException
     {
@@ -480,7 +483,7 @@
 
 
     /**
-     * @see BackingStore#close()
+     * @see org.apache.ldap.server.BackingStore#close()
      */
     public synchronized void close() throws NamingException
     {

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/SystemPartition.java	Fri Jan  7 08:01:15 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 import javax.naming.Name ;
 import javax.naming.NamingException ;
@@ -30,6 +30,7 @@
 import org.apache.ldap.server.db.Database;
 import org.apache.ldap.server.db.SearchEngine;
 import org.apache.ldap.server.db.SearchEngine;
+import org.apache.ldap.server.AbstractContextPartition;
 
 
 /**
@@ -202,7 +203,7 @@
 
 
     /**
-     * @see ContextPartition#getSuffix(boolean)
+     * @see org.apache.ldap.server.ContextPartition#getSuffix(boolean)
      */
     public final Name getSuffix( boolean normalized )
     {
@@ -215,7 +216,7 @@
 
 
     /**
-     * @see BackingStore#isSuffix(javax.naming.Name)
+     * @see org.apache.ldap.server.BackingStore#isSuffix(javax.naming.Name)
      */
     public final boolean isSuffix( Name dn )
     {

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/AuthenticationService.java	Fri Jan  7 08:01:15 2005
@@ -22,7 +22,7 @@
 import javax.naming.directory.Attributes;
 import javax.naming.directory.Attribute;
 
-import org.apache.eve.RootNexus;
+import org.apache.ldap.server.RootNexus;
 import org.apache.ldap.server.auth.LdapPrincipal;
 import org.apache.ldap.common.exception.*;
 import org.apache.ldap.common.message.ResultCodeEnum;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/BaseInterceptor.java	Fri Jan  7 08:01:15 2005
@@ -200,9 +200,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#add(String, Name, Attributes)}.
+     * {@link org.apache.ldap.server.BackingStore#add(String, Name, Attributes)}.
      *
-     * @see org.apache.eve.BackingStore#add(String, Name, Attributes)
+     * @see org.apache.ldap.server.BackingStore#add(String, Name, Attributes)
      */
     protected void add( String upName, Name normName, Attributes entry ) throws NamingException
     {
@@ -211,9 +211,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#delete(Name)}.
+     * {@link org.apache.ldap.server.BackingStore#delete(Name)}.
      *
-     * @see org.apache.eve.BackingStore#delete(Name)}
+     * @see org.apache.ldap.server.BackingStore#delete(Name)}
      */
     protected void delete( Name name ) throws NamingException
     {
@@ -222,9 +222,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.PartitionNexus#getMatchedDn(Name, boolean)}.
+     * {@link org.apache.ldap.server.PartitionNexus#getMatchedDn(Name, boolean)}.
      *
-     * @see org.apache.eve.PartitionNexus#getMatchedDn(Name, boolean)
+     * @see org.apache.ldap.server.PartitionNexus#getMatchedDn(Name, boolean)
      */
     protected void getMatchchedDn( Name dn, boolean normalized ) throws NamingException
     {
@@ -233,9 +233,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.ContextPartition#getSuffix(boolean)}.
+     * {@link org.apache.ldap.server.ContextPartition#getSuffix(boolean)}.
      *
-     * @see org.apache.eve.ContextPartition#getSuffix(boolean)
+     * @see org.apache.ldap.server.ContextPartition#getSuffix(boolean)
      */
     protected void getSuffix( Name dn, boolean normalized ) throws NamingException
     {
@@ -244,9 +244,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#hasEntry(Name)}.
+     * {@link org.apache.ldap.server.BackingStore#hasEntry(Name)}.
      *
-     * @see org.apache.eve.BackingStore#hasEntry(Name)
+     * @see org.apache.ldap.server.BackingStore#hasEntry(Name)
      */
     protected void hasEntry( Name dn ) throws NamingException
     {
@@ -255,9 +255,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#isSuffix(Name)}.
+     * {@link org.apache.ldap.server.BackingStore#isSuffix(Name)}.
      *
-     * @see org.apache.eve.BackingStore#isSuffix(Name)}
+     * @see org.apache.ldap.server.BackingStore#isSuffix(Name)}
      */
     protected void isSuffix( Name name ) throws NamingException
     {
@@ -266,9 +266,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#list(Name)}.
+     * {@link org.apache.ldap.server.BackingStore#list(Name)}.
      *
-     * @see org.apache.eve.BackingStore#list(Name)
+     * @see org.apache.ldap.server.BackingStore#list(Name)
      */
     protected void list( Name base ) throws NamingException
     {
@@ -277,9 +277,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.PartitionNexus#listSuffixes(boolean)}.
+     * {@link org.apache.ldap.server.PartitionNexus#listSuffixes(boolean)}.
      *
-     * @see org.apache.eve.PartitionNexus#listSuffixes(boolean)
+     * @see org.apache.ldap.server.PartitionNexus#listSuffixes(boolean)
      */
     protected void listSuffixes( boolean normalized ) throws NamingException
     {
@@ -288,9 +288,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#lookup(javax.naming.Name)}.
+     * {@link org.apache.ldap.server.BackingStore#lookup(javax.naming.Name)}.
      *
-     * @see org.apache.eve.BackingStore#lookup(javax.naming.Name)
+     * @see org.apache.ldap.server.BackingStore#lookup(javax.naming.Name)
      */
     protected void lookup( Name dn ) throws NamingException
     {
@@ -299,9 +299,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.PartitionNexus#lookup(javax.naming.Name, String[])}.
+     * {@link org.apache.ldap.server.PartitionNexus#lookup(javax.naming.Name, String[])}.
      *
-     * @see org.apache.eve.PartitionNexus#lookup(javax.naming.Name, String[])
+     * @see org.apache.ldap.server.PartitionNexus#lookup(javax.naming.Name, String[])
      */
     protected void lookup( Name dn, String[] attrIds ) throws NamingException
     {
@@ -310,9 +310,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#modify(Name, int, Attributes)}.
+     * {@link org.apache.ldap.server.BackingStore#modify(Name, int, Attributes)}.
      *
-     * @see org.apache.eve.BackingStore#modify(Name, int, Attributes)
+     * @see org.apache.ldap.server.BackingStore#modify(Name, int, Attributes)
      */
     protected void modify( Name dn, int modOp, Attributes mods ) throws NamingException
     {
@@ -321,9 +321,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#modify(Name, ModificationItem[])}.
+     * {@link org.apache.ldap.server.BackingStore#modify(Name, ModificationItem[])}.
      *
-     * @see org.apache.eve.BackingStore#modify(Name, ModificationItem[])
+     * @see org.apache.ldap.server.BackingStore#modify(Name, ModificationItem[])
      */
     protected void modify( Name dn, ModificationItem[] mods ) throws NamingException
     {
@@ -332,9 +332,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#modifyRn(Name, String, boolean)}.
+     * {@link org.apache.ldap.server.BackingStore#modifyRn(Name, String, boolean)}.
      *
-     * @see org.apache.eve.BackingStore#modifyRn(Name, String, boolean)
+     * @see org.apache.ldap.server.BackingStore#modifyRn(Name, String, boolean)
      */
     protected void modifyRdn( Name dn, String newRdn, boolean deleteOldRdn )
         throws NamingException
@@ -344,9 +344,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#move(Name, Name)}.
+     * {@link org.apache.ldap.server.BackingStore#move(Name, Name)}.
      *
-     * @see org.apache.eve.BackingStore#move(Name, Name)
+     * @see org.apache.ldap.server.BackingStore#move(Name, Name)
      */
     protected void move( Name oriChildName, Name newParentName ) throws NamingException
     {
@@ -355,9 +355,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#move(Name, Name, String, boolean)}.
+     * {@link org.apache.ldap.server.BackingStore#move(Name, Name, String, boolean)}.
      *
-     * @see org.apache.eve.BackingStore#move(Name, Name, String, boolean)
+     * @see org.apache.ldap.server.BackingStore#move(Name, Name, String, boolean)
      */
     protected void move( Name oriChildName, Name newParentName, String newRdn,
                          boolean deleteOldRdn ) throws NamingException
@@ -367,9 +367,9 @@
 
     /**
      * Override to inject functionality before, after or on error to
-     * {@link org.apache.eve.BackingStore#search(Name, Map, ExprNode, SearchControls)}.
+     * {@link org.apache.ldap.server.BackingStore#search(Name, Map, ExprNode, SearchControls)}.
      *
-     * @see org.apache.eve.BackingStore#search(Name, Map, ExprNode, SearchControls)
+     * @see org.apache.ldap.server.BackingStore#search(Name, Map, ExprNode, SearchControls)
      */
     protected void search( Name base, Map env, ExprNode filter,
                            SearchControls searchControls ) throws NamingException

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContext.java	Fri Jan  7 08:01:15 2005
@@ -31,8 +31,9 @@
 import org.apache.ldap.common.exception.LdapNoPermissionException;
 import org.apache.ldap.server.auth.LdapPrincipal;
 
-import org.apache.eve.PartitionNexus;
+import org.apache.ldap.server.PartitionNexus;
 import org.apache.ldap.server.auth.LdapPrincipal;
+import org.apache.ldap.server.PartitionNexus;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveContextFactory.java	Fri Jan  7 08:01:15 2005
@@ -47,10 +47,8 @@
 import org.apache.ldap.common.exception.LdapNoPermissionException;
 import org.apache.ldap.server.schema.bootstrap.BootstrapRegistries;
 
-import org.apache.eve.RootNexus;
-import org.apache.eve.SystemPartition;
-import org.apache.eve.ApplicationPartition;
-import org.apache.eve.ContextPartitionConfig;
+import org.apache.ldap.server.RootNexus;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.eve.protocol.LdapProtocolProvider;
 import org.apache.eve.db.*;
 import org.apache.ldap.server.db.jdbm.JdbmDatabase;
@@ -59,6 +57,9 @@
 import org.apache.ldap.server.jndi.ibs.*;
 import org.apache.ldap.server.db.jdbm.JdbmDatabase;
 import org.apache.ldap.server.db.*;
+import org.apache.ldap.server.ApplicationPartition;
+import org.apache.ldap.server.ContextPartitionConfig;
+import org.apache.ldap.server.*;
 import org.apache.seda.DefaultFrontend;
 import org.apache.seda.DefaultFrontendFactory;
 import org.apache.seda.listener.TCPListenerConfig;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveDirContext.java	Fri Jan  7 08:01:15 2005
@@ -41,8 +41,9 @@
 import org.apache.ldap.common.util.NamespaceTools;
 import org.apache.ldap.common.filter.FilterParserImpl;
 
-import org.apache.eve.PartitionNexus;
+import org.apache.ldap.server.PartitionNexus;
 import org.apache.ldap.server.auth.LdapPrincipal;
+import org.apache.ldap.server.PartitionNexus;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveJndiProvider.java	Fri Jan  7 08:01:15 2005
@@ -17,11 +17,12 @@
 package org.apache.ldap.server.jndi;
 
 
-import org.apache.eve.RootNexus;
-import org.apache.eve.PartitionNexus;
-import org.apache.eve.EveBackendSubsystem;
+import org.apache.ldap.server.RootNexus;
+import org.apache.ldap.server.PartitionNexus;
+import org.apache.ldap.server.EveBackendSubsystem;
 import org.apache.ldap.common.exception.LdapNamingException;
 import org.apache.ldap.common.message.ResultCodeEnum;
+import org.apache.ldap.server.EveBackendSubsystem;
 
 import java.util.Hashtable;
 
@@ -113,7 +114,7 @@
 
 
     /**
-     * @see org.apache.eve.EveBackendSubsystem#getLdapContext(Hashtable)
+     * @see org.apache.ldap.server.EveBackendSubsystem#getLdapContext(Hashtable)
      */
     public LdapContext getLdapContext( Hashtable env ) throws NamingException
     {

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/EveLdapContext.java	Fri Jan  7 08:01:15 2005
@@ -28,8 +28,9 @@
 
 import org.apache.ldap.common.NotImplementedException;
 
-import org.apache.eve.PartitionNexus;
+import org.apache.ldap.server.PartitionNexus;
 import org.apache.ldap.server.auth.LdapPrincipal;
+import org.apache.ldap.server.PartitionNexus;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/PartitionConfigBuilder.java	Fri Jan  7 08:01:15 2005
@@ -23,12 +23,13 @@
 import javax.naming.NamingException;
 import javax.naming.directory.Attributes;
 
-import org.apache.eve.ContextPartitionConfig;
+import org.apache.ldap.server.ContextPartitionConfig;
 import org.apache.ldap.common.message.LockableAttributesImpl;
 import org.apache.ldap.common.message.LockableAttributeImpl;
 import org.apache.ldap.common.util.ArrayUtils;
 import org.apache.ldap.common.util.StringTools;
 import org.apache.ldap.common.name.LdapName;
+import org.apache.ldap.server.ContextPartitionConfig;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/AuthorizationService.java	Fri Jan  7 08:01:15 2005
@@ -25,7 +25,7 @@
 import javax.naming.directory.SearchControls;
 import javax.naming.directory.SearchResult;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.db.SearchResultFilter;
 import org.apache.ldap.common.exception.LdapNoPermissionException;
 import org.apache.ldap.common.name.NameComponentNormalizer;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EveExceptionService.java	Fri Jan  7 08:01:15 2005
@@ -26,7 +26,7 @@
 import javax.naming.directory.SearchControls;
 import javax.naming.directory.Attribute;
 
-import org.apache.eve.RootNexus;
+import org.apache.ldap.server.RootNexus;
 import org.apache.ldap.server.exception.EveInterceptorException;
 import org.apache.ldap.common.exception.LdapException;
 import org.apache.ldap.common.exception.*;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/EventNotificationService.java	Fri Jan  7 08:01:15 2005
@@ -17,7 +17,7 @@
 package org.apache.ldap.server.jndi.ibs;
 
 
-import org.apache.eve.RootNexus;
+import org.apache.ldap.server.RootNexus;
 import org.apache.ldap.server.jndi.BaseInterceptor;
 
 

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterService.java	Fri Jan  7 08:01:15 2005
@@ -25,9 +25,9 @@
  * A service which applies a linear combination of filters to attributes before
  * they are returned from calls to the following operations:
  * <ul>
- *   <li><code>{@link org.apache.eve.BackingStore#lookup(javax.naming.Name)}</code></li>
- *   <li><code>{@link org.apache.eve.BackingStore#lookup(javax.naming.Name,String[])}</code></li>
- *   <li><code>{@link org.apache.eve.BackingStore#search(javax.naming.Name,
+ *   <li><code>{@link org.apache.ldap.server.BackingStore#lookup(javax.naming.Name)}</code></li>
+ *   <li><code>{@link org.apache.ldap.server.BackingStore#lookup(javax.naming.Name,String[])}</code></li>
+ *   <li><code>{@link org.apache.ldap.server.BackingStore#search(javax.naming.Name,
  * java.util.Map, org.apache.ldap.common.filter.ExprNode,
  * javax.naming.directory.SearchControls)}</code></li>
  * </ul>
@@ -40,8 +40,8 @@
     /**
      * Adds a new lookup filter to the end of the list of filters be applied to
      * attributes being returned to Eve JNDI Contexts from calls made to
-     * {@link org.apache.eve.BackingStore#lookup(javax.naming.Name)} and
-     * {@link org.apache.eve.BackingStore#lookup(javax.naming.Name,String[])}
+     * {@link org.apache.ldap.server.BackingStore#lookup(javax.naming.Name)} and
+     * {@link org.apache.ldap.server.BackingStore#lookup(javax.naming.Name,String[])}
      *
      * @param filter the filter to be added
      * @return the return value from {@link java.util.List#add(Object)}
@@ -52,7 +52,7 @@
     /**
      * Adds a new database search result filter to the end of the list of
      * filters be applied to attributes being returned via NamingEnumerations
-     * created via calls made to {@link org.apache.eve.BackingStore#search(
+     * created via calls made to {@link org.apache.ldap.server.BackingStore#search(
      * javax.naming.Name, java.util.Map, org.apache.ldap.common.filter.ExprNode,
      * javax.naming.directory.SearchControls)}
      *

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/FilterServiceImpl.java	Fri Jan  7 08:01:15 2005
@@ -41,9 +41,9 @@
  * An interceptor based service which manages the filtering of result responses
  * back to callers.  This service is strictly post invocation based and
  * operates upon Attributes and SearchResults obtained through
- * {@link org.apache.eve.BackingStore#lookup(Name)},
- * {@link org.apache.eve.BackingStore#lookup(Name,String[])} and
- * {@link org.apache.eve.BackingStore#search(Name, Map, ExprNode, SearchControls)}
+ * {@link org.apache.ldap.server.BackingStore#lookup(Name)},
+ * {@link org.apache.ldap.server.BackingStore#lookup(Name,String[])} and
+ * {@link org.apache.ldap.server.BackingStore#search(Name, Map, ExprNode, SearchControls)}
  * operations.
  * <p>
  * We try to limit the amount of filtering decorators used on search results and

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/LookupFilter.java	Fri Jan  7 08:01:15 2005
@@ -40,7 +40,7 @@
 {
     /**
      * Filters attributes to be returned from
-     * {@link org.apache.eve.BackingStore#lookup(Name)} operations.
+     * {@link org.apache.ldap.server.BackingStore#lookup(Name)} operations.
      *
      * @param dn the distinguished name of the entry looked up
      * @param entry the attributes of the entry that were looked up
@@ -52,7 +52,7 @@
 
     /**
      * Filters attributes to be returned from
-     * {@link org.apache.eve.BackingStore#lookup(Name,String[])} operations.
+     * {@link org.apache.ldap.server.BackingStore#lookup(Name,String[])} operations.
      *
      * @param dn the distinguished name of the entry looked up
      * @param entry the attributes of the entry that were looked up

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/OperationalAttributeService.java	Fri Jan  7 08:01:15 2005
@@ -23,7 +23,7 @@
 import javax.naming.ldap.LdapContext;
 import javax.naming.directory.*;
 
-import org.apache.eve.RootNexus;
+import org.apache.ldap.server.RootNexus;
 import org.apache.ldap.server.db.SearchResultFilter;
 import org.apache.ldap.server.jndi.Invocation;
 import org.apache.ldap.server.jndi.BaseInterceptor;
@@ -31,6 +31,7 @@
 import org.apache.ldap.server.schema.GlobalRegistries;
 import org.apache.ldap.server.schema.AttributeTypeRegistry;
 import org.apache.ldap.server.db.SearchResultFilter;
+import org.apache.ldap.server.RootNexus;
 
 import org.apache.ldap.common.util.DateUtils;
 import org.apache.ldap.common.schema.AttributeType;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/ReplicationService.java	Fri Jan  7 08:01:15 2005
@@ -17,8 +17,9 @@
 package org.apache.ldap.server.jndi.ibs;
 
 
-import org.apache.eve.RootNexus;
+import org.apache.ldap.server.RootNexus;
 import org.apache.ldap.server.jndi.BaseInterceptor;
+import org.apache.ldap.server.RootNexus;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/jndi/ibs/SchemaService.java	Fri Jan  7 08:01:15 2005
@@ -30,11 +30,12 @@
 import org.apache.ldap.server.jndi.BaseInterceptor;
 import org.apache.ldap.server.jndi.Invocation;
 import org.apache.ldap.server.jndi.InvocationStateEnum;
-import org.apache.eve.RootNexus;
+import org.apache.ldap.server.RootNexus;
 import org.apache.ldap.server.db.SearchResultFilter;
 import org.apache.ldap.server.schema.GlobalRegistries;
 import org.apache.ldap.server.schema.AttributeTypeRegistry;
 import org.apache.ldap.server.db.SearchResultFilter;
+import org.apache.ldap.server.RootNexus;
 
 import org.apache.ldap.common.schema.*;
 import org.apache.ldap.common.message.LockableAttributeImpl;

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalAttributeTypeRegistry.java	Fri Jan  7 08:01:15 2005
@@ -25,11 +25,12 @@
 import org.apache.ldap.common.util.JoinIterator;
 import org.apache.ldap.common.schema.AttributeType;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapAttributeTypeRegistry;
 import org.apache.ldap.server.schema.AttributeTypeRegistry;
 import org.apache.ldap.server.schema.AttributeTypeRegistryMonitor;
 import org.apache.ldap.server.schema.AttributeTypeRegistryMonitorAdapter;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalComparatorRegistry.java	Fri Jan  7 08:01:15 2005
@@ -23,11 +23,12 @@
 import javax.naming.NamingException;
 
 import org.apache.ldap.server.schema.bootstrap.BootstrapComparatorRegistry;
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapComparatorRegistry;
 import org.apache.ldap.server.schema.ComparatorRegistry;
 import org.apache.ldap.server.schema.ComparatorRegistryMonitor;
 import org.apache.ldap.server.schema.ComparatorRegistryMonitorAdapter;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitContentRuleRegistry.java	Fri Jan  7 08:01:15 2005
@@ -26,11 +26,12 @@
 import org.apache.ldap.common.util.JoinIterator;
 import org.apache.ldap.server.schema.bootstrap.BootstrapDitContentRuleRegistry;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapDitContentRuleRegistry;
 import org.apache.ldap.server.schema.DITContentRuleRegistry;
 import org.apache.ldap.server.schema.DITContentRuleRegistryMonitor;
 import org.apache.ldap.server.schema.DITContentRuleRegistryMonitorAdapter;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalDitStructureRuleRegistry.java	Fri Jan  7 08:01:15 2005
@@ -25,11 +25,12 @@
 import org.apache.ldap.common.schema.DITStructureRule;
 import org.apache.ldap.common.util.JoinIterator;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapDitStructureRuleRegistry;
 import org.apache.ldap.server.schema.DITStructureRuleRegistry;
 import org.apache.ldap.server.schema.DITStructureRuleRegistryMonitor;
 import org.apache.ldap.server.schema.DITStructureRuleRegistryMonitorAdapter;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleRegistry.java	Fri Jan  7 08:01:15 2005
@@ -26,8 +26,9 @@
 import org.apache.ldap.common.util.JoinIterator;
 import org.apache.ldap.server.schema.bootstrap.BootstrapMatchingRuleRegistry;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapMatchingRuleRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalMatchingRuleUseRegistry.java	Fri Jan  7 08:01:15 2005
@@ -25,8 +25,9 @@
 import org.apache.ldap.common.schema.MatchingRuleUse;
 import org.apache.ldap.common.util.JoinIterator;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapMatchingRuleUseRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNameFormRegistry.java	Fri Jan  7 08:01:15 2005
@@ -26,8 +26,9 @@
 import org.apache.ldap.common.util.JoinIterator;
 import org.apache.ldap.server.schema.bootstrap.BootstrapNameFormRegistry;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapNameFormRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalNormalizerRegistry.java	Fri Jan  7 08:01:15 2005
@@ -24,8 +24,9 @@
 import org.apache.ldap.common.schema.Normalizer;
 import org.apache.ldap.server.schema.bootstrap.BootstrapNormalizerRegistry;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapNormalizerRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalObjectClassRegistry.java	Fri Jan  7 08:01:15 2005
@@ -26,8 +26,9 @@
 import org.apache.ldap.common.util.JoinIterator;
 import org.apache.ldap.server.schema.bootstrap.BootstrapObjectClassRegistry;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapObjectClassRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalOidRegistry.java	Fri Jan  7 08:01:15 2005
@@ -25,9 +25,10 @@
 
 import javax.naming.NamingException;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapOidRegistry;
 import org.apache.ldap.server.schema.bootstrap.BootstrapOidRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalRegistries.java	Fri Jan  7 08:01:15 2005
@@ -28,7 +28,8 @@
 import org.apache.ldap.common.schema.MatchingRule;
 import org.apache.ldap.common.schema.AttributeType;
 import org.apache.ldap.server.schema.bootstrap.*;
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxCheckerRegistry.java	Fri Jan  7 08:01:15 2005
@@ -23,8 +23,9 @@
 
 import org.apache.ldap.common.schema.SyntaxChecker;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapSyntaxCheckerRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java&r2=124524
==============================================================================
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/schema/GlobalSyntaxRegistry.java	Fri Jan  7 08:01:15 2005
@@ -26,8 +26,9 @@
 import org.apache.ldap.common.util.JoinIterator;
 import org.apache.ldap.server.schema.bootstrap.BootstrapSyntaxRegistry;
 
-import org.apache.eve.SystemPartition;
+import org.apache.ldap.server.SystemPartition;
 import org.apache.ldap.server.schema.bootstrap.BootstrapSyntaxRegistry;
+import org.apache.ldap.server.SystemPartition;
 
 
 /**
--- incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java	(original)
+++ incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/AbstractContextPartition.java	Fri Jan  7 08:01:15 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.eve;
+package org.apache.ldap.server;
 
 
 import java.util.Map;
@@ -229,7 +229,7 @@
 
 
     /**
-     * @see org.apache.eve.BackingStore#delete( Name )
+     * @see org.apache.ldap.server.BackingStore#delete( Name )
      */
     public void delete( Name dn ) throws NamingException
     {
@@ -255,7 +255,7 @@
     
 
     /**
      * @see org.apache.eve.BackingStore#add( String, Name, Attributes )
      */
     public void add( String updn, Name dn, Attributes entry ) throws NamingException
     {
@@ -264,7 +264,7 @@
 
 
     /**
      * @see org.apache.eve.BackingStore#modify( Name, int, Attributes )
      */
     public void modify( Name dn, int modOp, Attributes mods ) throws NamingException
     {
@@ -273,7 +273,7 @@
 
 
     /**
-     * @see org.apache.eve.BackingStore#modify( Name,ModificationItem[] )
+     * @see org.apache.ldap.server.BackingStore#modify( Name,ModificationItem[] )
      */
     public void modify( Name dn, ModificationItem[] mods ) throws NamingException
     {
@@ -282,7 +282,7 @@
 
 
     /**
-     * @see org.apache.eve.BackingStore#list( Name )
+     * @see org.apache.ldap.server.BackingStore#list( Name )
      */
     public NamingEnumeration list( Name base ) throws NamingException
     {
@@ -294,7 +294,7 @@
     
     
     /**
      * @see org.apache.eve.BackingStore#search(Name, Map, ExprNode, SearchControls)
      */
     public NamingEnumeration search( Name base, Map env, ExprNode filter,
                                      SearchControls searchCtls )
@@ -310,7 +310,7 @@
 
 
     /**
-     * @see org.apache.eve.BackingStore#lookup( Name )
+     * @see org.apache.ldap.server.BackingStore#lookup( Name )
      */
     public Attributes lookup( Name dn ) throws NamingException
     {
@@ -346,7 +346,7 @@
 
 
     /**
-     * @see org.apache.eve.BackingStore#hasEntry( Name )
+     * @see org.apache.ldap.server.BackingStore#hasEntry( Name )
      */
     public boolean hasEntry( Name dn ) throws NamingException
     {
@@ -364,7 +364,7 @@
 
 
     /**
      * @see org.apache.eve.BackingStore#move( Name, Name )
      */
     public void move( Name oldChildDn, Name newParentDn ) throws NamingException
     {
@@ -373,7 +373,7 @@
     
 
     /**
      * @see org.apache.eve.BackingStore#move( Name, Name, String, boolean )
      */
     public void move( Name oldChildDn, Name newParentDn, String newRdn,
         boolean deleteOldRdn ) throws NamingException
@@ -255,7 +255,7 @@
 
     /**
-     * @see org.apache.eve.BackingStore#add( String, Name, Attributes )
+     * @see org.apache.ldap.server.BackingStore#add( String, Name, Attributes )
      */
     public void add( String updn, Name dn, Attributes entry ) throws NamingException
@@ -264,7 +264,7 @@
 
     /**
-     * @see org.apache.eve.BackingStore#modify( Name, int, Attributes )
+     * @see org.apache.ldap.server.BackingStore#modify( Name, int, Attributes )
      */
     public void modify( Name dn, int modOp, Attributes mods ) throws NamingException
@@ -294,7 +294,7 @@
     
     /**
-     * @see org.apache.eve.BackingStore#search(Name, Map, ExprNode, SearchControls)
+     * @see org.apache.ldap.server.BackingStore#search(Name, Map, ExprNode, SearchControls)
      */
     public NamingEnumeration search( Name base, Map env, ExprNode filter,
@@ -364,7 +364,7 @@
 
     /**
-     * @see org.apache.eve.BackingStore#move( Name, Name )
+     * @see org.apache.ldap.server.BackingStore#move( Name, Name )
      */
     public void move( Name oldChildDn, Name newParentDn ) throws NamingException
@@ -373,7 +373,7 @@
 
     /**
-     * @see org.apache.eve.BackingStore#move( Name, Name, String, boolean )
+     * @see org.apache.ldap.server.BackingStore#move( Name, Name, String, boolean )
      */
     public void move( Name oldChildDn, Name newParentDn, String newRdn,

Modified: incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java
Url: http://svn.apache.org/viewcvs/incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java?view=diff&rev=124524&p1=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java&r1=124523&p2=incubator/directory/server/trunk/core/src/main/java/org/apache/ldap/server/ApplicationPartition.java&r2=124524
==============================================================================